#
# spec file for package synfigstudio
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname synfigapp
%define sover 0
%define prjname synfig
Name:           synfigstudio
Version:        1.2.0
Release:        150400.3.pm.3
Summary:        Vector based 2D animation studio
License:        GPL-3.0+
Group:          Productivity/Graphics/Vector Editors
Url:            http://synfig.org
Source0:        https://sourceforge.net/projects/synfig/files/releases/1.0.2/source/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE debug.patch avvissu@yandex.by -- Specify the `-g' option when building
Patch0:         synfigstudio-1.0.2_debug.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  dejavu-fonts
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gnu-free-fonts
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  ladspa
BuildRequires:  libmlt7-modules
BuildRequires:  libtool
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(ETL)
BuildRequires:  pkgconfig(gtkmm-3.0) >= 3.14.0
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(synfig) >= %{version}
BuildRequires:  fdupes
Requires:       ladspa
Requires:       libmlt7-modules

%description
%{summary}.

This package contains the GUI interface to create synfig animations which
are saved in synfig .sif or .sifz format.

%package -n     lib%{soname}%{sover}
Summary:        Shared library part of %{name}
Group:          System/Libraries
Provides:       lib%{name}%{sover} = %{version}

%description -n lib%{soname}%{sover}
Vector based 2D animation studio.

This package contains the shared library.

%package -n     %{soname}-devel
Summary:        Header files and static library for the %{name} library
Group:          Development/Libraries/C and C++
Requires:       lib%{soname}%{sover} = %{version}
Provides:       %{name} = %{version}
Provides:       lib%{soname}-devel = %{version}
Obsoletes:      lib%{soname}-devel < %{version}

%description -n %{soname}-devel
Vector based 2D animation studio.

This package contains the pkgconfig, header files and libraries needed to
develop application that use %{name}.

%lang_package

%prep
%autosetup -p1

%build
# Don't compile in DATE and TIME
BUILDDATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%b %d %Y')
BUILDTIME=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%H:%M')
sed -e "s/__DATE__/\"$BUILDDATE\"/" \
    -e "s/__TIME__/\"$BUILDTIME\"/" \
    -i $(grep -rl '__DATE__\|__TIME__')
    
# Don't use imagedir in pixmaps
sed -i '/icondir/!s/pixmaps//' $(grep -rl pixmaps)

autoreconf -fiv
intltoolize -f
CFLAGS='%optflags -Wno-deprecated-declarations'
CXXFLAGS='%optflags -Wno-deprecated-declarations -Wno-deprecated-copy -std=gnu++11'
%configure \
    --sysconfdir=%{_sysconfdir}/%{prjname} \
    --with-userdir=.%{prjname}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file -r %{name} Graphics VectorGraphics

# Remove conflicting files
pushd %{buildroot}%{_datadir}/mime
for i in $(ls -1F %{_datadir}/mime|grep -v '/'); do 
find . -type f -iname "$i" -delete -print; done
popd

find %{buildroot} -type f -name \*.la -delete -print

%fdupes -s %{buildroot}%{_datadir}

%post
%mime_database_post
%icon_theme_cache_post
%desktop_database_post

%postun
%mime_database_postun
%icon_theme_cache_postun
%desktop_database_postun

%post -n lib%{soname}%{sover} -p /sbin/ldconfig
%postun -n lib%{soname}%{sover} -p /sbin/ldconfig

%files
%license COPYING
%doc NEWS
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/appdata/%{name}*.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{prjname}_*.??g
%{_datadir}/mime-info
%{_datadir}/mime
%{_datadir}/pixmaps/sif_*.png
%{_datadir}/pixmaps/%{prjname}_*.png
%{_datadir}/%{prjname}
%dir %{_datadir}/appdata

%files -n lib%{soname}%{sover}
%{_libdir}/lib%{soname}.so.*

%files -n %{soname}-devel
%{_includedir}/%{soname}*/
%{_libdir}/lib%{soname}.so

%files lang -f %{name}.lang

%changelog
* Wed Jan 11 2017 avvissu@yandex.by
- Update to 1.2.0:
  * see: /usr/share/doc/packages/synfigstudio/NEWS
- Drop patch (fixed in upstream):
  * synfigstudio-1.0.2_c++11.patch
  * synfigstudio-isnan.patch
  * synfigstudio-math_h.patch
* Sun Apr  3 2016 avvissu@yandex.by
- Update to 1.0.2:
  * see: /usr/share/doc/packages/synfigstudio/NEWS
- Remove patches:
  * synfigstudio-0.64.1_gcc48.patch	(fixed in upstream)
  * synfigstudio-sequence-point.patch (fixed in upstream)
  * synfigstudio-no-buildtimestamp.patch (use sed in spec-file)
- Update patches:
  * synfigstudio-debug.patch -> synfigstudio-1.0.2_debug.patch
- Add patches:
  * synfigstudio-1.0.2_c++11.patch
- Add BuildRequires: dejavu-fonts gnu-free-fonts ladspa libmlt6
- Add additional settings: --sysconfdir --with-userdir
- Use %%post(un) for package with app
- Cleanup the descriptions for packages
- Spec-file cleanup
* Mon Jun 22 2015 olaf@aepfle.de
- update to 1.0
* Fri Mar 28 2014 seife+obs@b1-systems.com
- add patch to fix build with gcc 4.8 (13.1+)
- remove build date from binaries to avoid unneeded republishing
* Fri Nov  8 2013 Manfred.Tremmel@iiv.de
- readded synfigstudio-images tarball
* Thu Nov  7 2013 obs@botter.cc
- add patch to fix configure (stupig sed to remove -g option from CFLAGS
* Tue Nov  5 2013 obs@botter.cc
- update to 0.64.1
* Sun Apr 15 2012 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.05-0
- update to 0.63.05
* Sun Oct 23 2011 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.02-1.pm.1
- update to 0.63.02
* Sat Jun 11 2011 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.00-0.pm.1
- update to 0.63.00 (git logout, because there's no source tarball)
* Mon Nov 15 2010 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.02-1.pm.1
- update to 0.62.02
* Wed Jul 14 2010 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.01-1.pm.1
- update to 0.62.01
* Wed Nov  4 2009 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.00-0.pm.1
- update to 0.62.00
* Sat Sep  5 2009 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.61.09-1.pm.1
- cleanups where rpmlint wasn't so happy
* Sat Jan  3 2009 Manfred.Tremmel@iiv.de
- remove NX in 11.1, it's no longer available
* Sat Oct 25 2008 Manfred.Tremmel@iiv.de
- update to 0.61.09
* Tue Mar  4 2008 Manfred.Tremmel@iiv.de
- update to 0.61.08
* Sat Feb 23 2008 Manfred.Tremmel@iiv.de
- update to svn (Revision 1808), because off security reasons
* Fri Oct 12 2007 Manfred.Tremmel@iiv.de
- update to 0.61.07
* Sat Jun 23 2007 Manfred.Tremmel@iiv.de
- update to 0.61.06
* Sun Dec 24 2006 Manfred.Tremmel@iiv.de
- update to svn (Revision 229), seems, a lot of bugs where fixed inbetween
* Thu Dec 21 2006 Manfred.Tremmel@iiv.de
- added --enable-optimization=1 to make it compile on SUSE 10.2
* Sat May  6 2006 Manfred.Tremmel@iiv.de
- use -fno-inline with SUSE 10.1, because of a compiler bug in gcc 4.1
* Wed Mar  1 2006 Manfred.Tremmel@iiv.de
- update to 0.61.05
* Mon Jan 23 2006 Manfred.Tremmel@iiv.de
- recompile with new libffmpeg version
* Sun Jan 15 2006 Manfred.Tremmel@iiv.de
- update to 0.61.04
* Thu Dec 15 2005 Manfred.Tremmel@iiv.de
- first packman build, based on the spec-file
  from Robert B. Quattlebaum Jr. <darco@bigfoot.com>
